from __future__ import annotations
from kiota_abstractions.serialization import AdditionalDataHolder, Parsable, ParseNode, SerializationWriter
from kiota_abstractions.utils import lazy_import
from typing import Any, Callable, Dict, List, Optional, Union

search_bucket = lazy_import('msgraph.generated.models.search_bucket')

class SearchAggregation(AdditionalDataHolder, Parsable):
    @property
    def additional_data(self,) -> Dict[str, Any]:
        """
        Gets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
        Returns: Dict[str, Any]
        """
        return self._additional_data
    
    @additional_data.setter
    def additional_data(self,value: Dict[str, Any]) -> None:
        """
        Sets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
        Args:
            value: Value to set for the AdditionalData property.
        """
        self._additional_data = value
    
    @property
    def buckets(self,) -> Optional[List[search_bucket.SearchBucket]]:
        """
        Gets the buckets property value. Defines the actual buckets of the computed aggregation.
        Returns: Optional[List[search_bucket.SearchBucket]]
        """
        return self._buckets
    
    @buckets.setter
    def buckets(self,value: Optional[List[search_bucket.SearchBucket]] = None) -> None:
        """
        Sets the buckets property value. Defines the actual buckets of the computed aggregation.
        Args:
            value: Value to set for the buckets property.
        """
        self._buckets = value
    
    def __init__(self,) -> None:
        """
        Instantiates a new searchAggregation and sets the default values.
        """
        # Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
        self._additional_data: Dict[str, Any] = {}

        # Defines the actual buckets of the computed aggregation.
        self._buckets: Optional[List[search_bucket.SearchBucket]] = None
        # Defines on which field the aggregation was computed on.
        self._field: Optional[str] = None
        # The OdataType property
        self._odata_type: Optional[str] = None
    
    @staticmethod
    def create_from_discriminator_value(parse_node: Optional[ParseNode] = None) -> SearchAggregation:
        """
        Creates a new instance of the appropriate class based on discriminator value
        Args:
            parseNode: The parse node to use to read the discriminator value and create the object
        Returns: SearchAggregation
        """
        if parse_node is None:
            raise Exception("parse_node cannot be undefined")
        return SearchAggregation()
    
    @property
    def field(self,) -> Optional[str]:
        """
        Gets the field property value. Defines on which field the aggregation was computed on.
        Returns: Optional[str]
        """
        return self._field
    
    @field.setter
    def field(self,value: Optional[str] = None) -> None:
        """
        Sets the field property value. Defines on which field the aggregation was computed on.
        Args:
            value: Value to set for the field property.
        """
        self._field = value
    
    def get_field_deserializers(self,) -> Dict[str, Callable[[ParseNode], None]]:
        """
        The deserialization information for the current model
        Returns: Dict[str, Callable[[ParseNode], None]]
        """
        fields = {
            "buckets": lambda n : setattr(self, 'buckets', n.get_collection_of_object_values(search_bucket.SearchBucket)),
            "field": lambda n : setattr(self, 'field', n.get_str_value()),
            "@odata.type": lambda n : setattr(self, 'odata_type', n.get_str_value()),
        }
        return fields
    
    @property
    def odata_type(self,) -> Optional[str]:
        """
        Gets the @odata.type property value. The OdataType property
        Returns: Optional[str]
        """
        return self._odata_type
    
    @odata_type.setter
    def odata_type(self,value: Optional[str] = None) -> None:
        """
        Sets the @odata.type property value. The OdataType property
        Args:
            value: Value to set for the OdataType property.
        """
        self._odata_type = value
    
    def serialize(self,writer: SerializationWriter) -> None:
        """
        Serializes information the current object
        Args:
            writer: Serialization writer to use to serialize this model
        """
        if writer is None:
            raise Exception("writer cannot be undefined")
        writer.write_collection_of_object_values("buckets", self.buckets)
        writer.write_str_value("field", self.field)
        writer.write_str_value("@odata.type", self.odata_type)
        writer.write_additional_data_value(self.additional_data)
    

